@@ -12,7 +12,7 @@ def rotate_pos(pos, angle=None, root_ind=None):
         
     """
     
-    angle = None
+    # angle = None
     if angle is not None:
         theta = angle * np.pi / 180
     elif root_ind is not None:
